@@ -326,15 +326,16 @@ public class ProjectsCaller {
 	 * @param profileID the profile ID
 	 * @param projectID the project ID
 	 * @param stepID    the step ID
+	 * @param optionalMessage the optional message
 	 * @param options   the options
 	 * @return the project
 	 * @throws Exception the exception
 	 */
-	public Project performStep(String profileID, String projectID, String stepID, Document options) throws Exception {
-		LOG.info("performStep called for profileID: {}, projectID: {}", profileID, projectID);
+	public Project performStep(String profileID, String projectID, String stepID, String optionalMessage, Document options) throws Exception {
+		LOG.info("performStep called for profileID: {}, projectID: {}. Optional message exists?: {}", profileID, projectID, optionalMessage!=null);
 		Projects<Project> client = (Projects<Project>) getClient(profileID);
-		StepExecutionRequest request = new StepExecutionRequest(stepID, options);
-		Project project = client.performStep(projectID, request);
+		StepExecutionRequest request = new StepExecutionRequest(stepID, optionalMessage, options);
+		Project project = client.performStep(projectID, optionalMessage, request);
 
 		LOG.info("performStep returning project ID: " + project.getId());
 		return project;
